@@ -1,5 +1,5 @@
 pn <-
-function(sims, p=1:50, anchor=NULL, ts=FALSE, ...){
+function(sims, p=1:50, anchor=NULL, ...){
 	if(min(p)<0 | max(p)>100)
 		stop("all percentiles must be between 0 and 100")
 	p<-c(p,100-p)
@@ -9,7 +9,7 @@ function(sims, p=1:50, anchor=NULL, ts=FALSE, ...){
 	if(!is.null(anchor)){
 		pp<-rbind(rep(anchor,length(p)),pp)
 	}
-	if(ts==TRUE)	pp<-ts(pp, ...)
+	pp<-ts(pp, ...)
 	class(pp)<-"pn"
 	return(pp)
 }
